@@ -9,7 +9,7 @@ use Crypt::NSS config_dir => "db", cipher_suite => "US";
 
 @Net::HTTPS::ISA = qw(Net::NSS::SSL::LWPCompat Net::HTTP::Methods);
 
-Crypt::NSS::PKCS11->set_default_pkcs11_pin_arg("crypt-nss");
+local $Crypt::NSS::PKCS11::DefaultPinArg = "crypt-nss";
 
 my $content = get("https://www.mozilla.org");
 
